API Reference
=============

This section contains the complete API documentation for shepherd-score, automatically 
generated from the source code docstrings.

Core Modules
------------

.. toctree::
   :maxdepth: 2

   container
   conformer
   extraction

Scoring
-------

.. toctree::
   :maxdepth: 2

   scoring

Alignment
---------

.. toctree::
   :maxdepth: 2

   alignment

Evaluations
-----------

.. toctree::
   :maxdepth: 2

   evaluations

Utilities
---------

.. toctree::
   :maxdepth: 2

   pharmacophore
   protonation
   visualization
